@@ -298,7 +298,8 @@ class MongoEngineResource(resources.ModelResource):
 
         self._meta.queryset._document._collection = None
         self._meta.queryset._collection_obj = self._meta.queryset._document._get_collection()
-        self._meta.queryset._reset_already_indexed()
+        if hasattr(self._meta.queryset, '_reset_already_indexed'):
+            self._meta.queryset._reset_already_indexed()
 
     def get_object_list(self, request):
         """
@@ -458,6 +459,9 @@ class MongoEngineResource(resources.ModelResource):
                             value = field_object.default()
                         else:
                             value = field_object.default
+                    # If it can be blank, we leave the field as it is, it was possibly already populated or it is not even necessary to be
+                    elif field_object.blank:
+                        pass
                     else:
                         value = None
                 else:
