@@ -1124,7 +1124,9 @@ class BasicTest(test_runner.MongoEngineTestCase):
 
         # Test fallback
         # Because the resource is not registered, it should be added on the mongoengine layer
-        unreg_company = resources.UnregisteredCompanyResource()._meta.object_class(corporate_name='Unreg company', phone='000-000000')
+        unreg_company_resource = resources.UnregisteredCompanyResource()
+        unreg_company_resource._reset_collection()
+        unreg_company = unreg_company_resource._meta.object_class(corporate_name='Unreg company', phone='000-000000')
         unreg_company.save()
 
         response = self.c.get(self.resourceListURI('contact'), content_type='application/json')
@@ -1132,9 +1134,16 @@ class BasicTest(test_runner.MongoEngineTestCase):
         response = json.loads(response.content)
 
         self.assertEqual(response['meta']['total_count'], 3)
-        self.assertEqual(response['objects'][2]['resource_uri'], self.resourceDetailURI('company', unreg_company.id))
-        self.assertEqual(response['objects'][2]['resource_type'], 'unregisteredcompany')
-        self.assertEqual(response['objects'][2]['corporate_name'], 'Unreg company')
+
+        unreg_company_obj = None
+        for obj in response['objects']:
+            if obj['resource_type'] == 'unregisteredcompany':
+                unreg_company_obj = obj
+                break
+
+        self.assertEqual(unreg_company_obj['resource_uri'], self.resourceDetailURI('company', unreg_company.id))
+        self.assertEqual(unreg_company_obj['resource_type'], 'unregisteredcompany')
+        self.assertEqual(unreg_company_obj['corporate_name'], 'Unreg company')
 
     def test_polymorphic_duplicate_class(self):
         with self.assertRaises(exceptions.ImproperlyConfigured):
@@ -1509,6 +1518,9 @@ class BasicTest(test_runner.MongoEngineTestCase):
         self.assertEqual(response['embedded']['name'], 'A blank name')
         self.assertEqual(response['embedded']['description'], None)
 
+        response = self.c.patch(document_uri, '{"embedded": null}', content_type='application/json')
+        self.assertContains(response, 'Field is required', status_code=400)
+
     def test_readonly_embedded(self):
         response = self.c.post(self.resourceListURI('readonlyparent'), '{"name": "A readonly embedded test"}', content_type='application/json')
         self.assertEqual(response.status_code, 201)
@@ -1521,3 +1533,36 @@ class BasicTest(test_runner.MongoEngineTestCase):
 
         self.assertEqual(response['tzdt']['dt'], '2012-12-12T12:12:12')
         self.assertEqual(response['tzdt']['tz'], 'UTC')
+
+        response = self.c.patch(document_uri, '{"tzdt": {"dt": "2012-12-12T12:00:00"}}', content_type='application/json')
+        # Tastypie still accepts the request, just does not act on it
+        # TODO: Should Tastypie return a failure status code?
+        self.assertEqual(response.status_code, 202)
+
+        response = self.c.get(document_uri)
+        self.assertEqual(response.status_code, 200)
+        response = json.loads(response.content)
+
+        self.assertEqual(response['tzdt']['dt'], '2012-12-12T12:12:12')
+        self.assertEqual(response['tzdt']['tz'], 'UTC')
+
+    def test_datetime(self):
+        response = self.c.post(self.resourceListURI('datetimefieldtest'), '{"datetime": "2012-12-12T12:12:12"}', content_type='application/json')
+        self.assertEqual(response.status_code, 201)
+
+        datetimefieldtest_uri = response['location']
+
+        response = self.c.get(datetimefieldtest_uri)
+        self.assertEqual(response.status_code, 200)
+        response = json.loads(response.content)
+
+        self.assertEqual(response['datetime'], '2012-12-12T12:12:12')
+
+        response = self.c.patch(datetimefieldtest_uri, '{"datetime": "2012-12-12T12:00:00"}', content_type='application/json')
+        self.assertEqual(response.status_code, 202)
+
+        response = self.c.get(datetimefieldtest_uri)
+        self.assertEqual(response.status_code, 200)
+        response = json.loads(response.content)
+
+        self.assertEqual(response['datetime'], '2012-12-12T12:00:00')
